SetExpr

Enum SetExpr 

pub enum SetExpr {
    Select(Box<Select>),
    Query(Box<Query>),
    SetOperation {
        op: SetOperator,
        set_quantifier: SetQuantifier,
        left: Box<SetExpr>,
        right: Box<SetExpr>,
    },
    Values(Values),
    Insert(Statement),
    Update(Statement),
    Delete(Statement),
    Merge(Statement),
    Table(Box<Table>),
}
A node in a tree, representing a “query body” expression, roughly: SELECT ... [ {UNION|EXCEPT|INTERSECT} SELECT ...]

Variants



Select(Box<Select>)

Restricted SELECT .. FROM .. HAVING (no ORDER BY or set operations)



Query(Box<Query>)

Parenthesized SELECT subquery, which may include more set operations in its body and an optional ORDER BY / LIMIT.



SetOperation

UNION/EXCEPT/INTERSECT of two queries A set operation combining two query expressions.

Fields

op: SetOperator

The set operator used (e.g. UNION, EXCEPT).

set_quantifier: SetQuantifier

Optional quantifier (ALL, DISTINCT, etc.).

left: Box<SetExpr>

Left operand of the set operation.

right: Box<SetExpr>

Right operand of the set operation.



Values(Values)

VALUES (...)



Insert(Statement)

INSERT statement



Update(Statement)

UPDATE statement



Delete(Statement)

DELETE statement



Merge(Statement)

MERGE statement



Table(Box<Table>)

TABLE command

Implementations

Source

impl SetExpr

pub fn as_select(&self) -> Option<&Select>

If this SetExpr is a SELECT, returns the Select.