SqlOption

Enum SqlOption 

pub enum SqlOption {
    Clustered(TableOptionsClustered),
    Ident(Ident),
    KeyValue {
        key: Ident,
        value: Expr,
    },
    Partition {
        column_name: Ident,
        range_direction: Option<PartitionRangeDirection>,
        for_values: Vec<Expr>,
    },
    Comment(CommentDef),
    TableSpace(TablespaceOption),
    NamedParenthesizedList(NamedParenthesizedList),
}
SQL option syntax used in table and server definitions.

Variants



Clustered(TableOptionsClustered)



Ident(Ident)



KeyValue

Any option that consists of a key value pair where the value is an expression. e.g.

WITH(DISTRIBUTION = ROUND_ROBIN)

Fields

key: Ident

The option key identifier.

value: Expr

The expression value for the option.



Partition

One or more table partitions and represents which partition the boundary values belong to, e.g.

PARTITION (id RANGE LEFT FOR VALUES (10, 20, 30, 40))

https://learn.microsoft.com/en-us/sql/t-sql/statements/create-table-azure-sql-data-warehouse?view=aps-pdw-2016-au7#TablePartitionOptions

Fields

column_name: Ident

The partition column name.

range_direction: Option<PartitionRangeDirection>

Optional direction for the partition range (LEFT/RIGHT).

for_values: Vec<Expr>

Values that define the partition boundaries.



Comment(CommentDef)

Comment parameter (supports = and no = syntax)



TableSpace(TablespaceOption)



NamedParenthesizedList(NamedParenthesizedList)

An option representing a key value pair, where the value is a parenthesized list and with an optional name e.g.

UNION = (tbl_name[,tbl_name]…) https://dev.mysql.com/doc/refman/8.4/en/create-table.html ENGINE = ReplicatedMergeTree(‘/table_name’,‘{replica}’, ver) https://clickhouse.com/docs/engines/table-engines/mergetree-family/replication ENGINE = SummingMergeTree([columns]) https://clickhouse.com/docs/engines/table-engines/mergetree-family/summingmergetree