Merge

Struct Merge 

pub struct Merge {
    pub merge_token: AttachedToken,
    pub optimizer_hint: Option<OptimizerHint>,
    pub into: bool,
    pub table: TableFactor,
    pub source: TableFactor,
    pub on: Box<Expr>,
    pub clauses: Vec<MergeClause>,
    pub output: Option<OutputClause>,
}
A MERGE statement.

Fields

merge_token: AttachedToken

The MERGE token that starts the statement.

optimizer_hint: Option<OptimizerHint>

A query optimizer hint

Oracle

into: bool

optional INTO keyword

table: TableFactor

Specifies the table to merge

source: TableFactor

Specifies the table or subquery to join with the target table

on: Box<Expr>

Specifies the expression on which to join the target table and source

clauses: Vec<MergeClause>

Specifies the actions to perform when values match or do not match.

output: Option<OutputClause>

Specifies the output to save changes in MSSQL