TableAlias

Struct TableAlias 

pub struct TableAlias {
    pub explicit: bool,
    pub name: Ident,
    pub columns: Vec<TableAliasColumnDef>,
}
An alias for a table reference, optionally including an explicit AS and column names.

Fields

explicit: bool

Tells whether the alias was introduced with an explicit, preceding “AS” keyword, e.g. AS name. Typically, the keyword is preceding the name (e.g. .. FROM table AS t ..).

name: Ident

Alias identifier for the table.

columns: Vec<TableAliasColumnDef>

Optional column aliases declared in parentheses after the table alias.