TableAliasColumnDef

Struct TableAliasColumnDef 

pub struct TableAliasColumnDef {
    pub name: Ident,
    pub data_type: Option<DataType>,
}
SQL column definition in a table expression alias. Most of the time, the data type is not specified. But some table-valued functions do require specifying the data type.

See https://www.postgresql.org/docs/17/queries-table-expressions.html#QUERIES-TABLEFUNCTIONS

Fields

name: Ident

Column name alias

data_type: Option<DataType>

Some table-valued functions require specifying the data type in the alias.

Implementations

Source

impl TableAliasColumnDef

pub fn from_name<S>(name: S) -> TableAliasColumnDef
where S: Into<String>,

Create a new table alias column definition with only a name and no type