WithFill

Struct WithFill 

pub struct WithFill {
    pub from: Option<Expr>,
    pub to: Option<Expr>,
    pub step: Option<Expr>,
}
ClickHouse WITH FILL modifier for ORDER BY clause. Supported by ClickHouse syntax

WITH FILL options for ClickHouse ORDER BY expressions.

Fields

from: Option<Expr>

Optional lower bound expression for the fill range (FROM <expr>).

to: Option<Expr>

Optional upper bound expression for the fill range (TO <expr>).

step: Option<Expr>

Optional step expression specifying interpolation step (STEP <expr>).