FullTextOrSpatialConstraint

Struct FullTextOrSpatialConstraint 

pub struct FullTextOrSpatialConstraint {
    pub fulltext: bool,
    pub index_type_display: KeyOrIndexDisplay,
    pub opt_index_name: Option<Ident>,
    pub columns: Vec<IndexColumn>,
}
MySQLs fulltext definition. Since the SPATIAL definition is exactly the same, and MySQL displays both the same way, it is part of this definition as well.

Supported syntax:

{FULLTEXT | SPATIAL} [INDEX | KEY] [index_name] (key_part,...)

key_part: col_name

Fields

fulltext: bool

Whether this is a FULLTEXT (true) or SPATIAL (false) definition.

index_type_display: KeyOrIndexDisplay

Whether the type is followed by the keyword KEY, INDEX, or no keyword at all.

opt_index_name: Option<Ident>

Optional index name.

columns: Vec<IndexColumn>

Referred column identifier list.