AlterTableOperation

Enum AlterTableOperation 

pub enum AlterTableOperation {
Show 52 variants AddConstraint { constraint: TableConstraint, not_valid: bool, }, AddColumn { column_keyword: bool, if_not_exists: bool, column_def: ColumnDef, column_position: Option<MySQLColumnPosition>, }, AddProjection { if_not_exists: bool, name: Ident, select: ProjectionSelect, }, DropProjection { if_exists: bool, name: Ident, }, MaterializeProjection { if_exists: bool, name: Ident, partition: Option<Ident>, }, ClearProjection { if_exists: bool, name: Ident, partition: Option<Ident>, }, DisableRowLevelSecurity, DisableRule { name: Ident, }, DisableTrigger { name: Ident, }, DropConstraint { if_exists: bool, name: Ident, drop_behavior: Option<DropBehavior>, }, DropColumn { has_column_keyword: bool, column_names: Vec<Ident>, if_exists: bool, drop_behavior: Option<DropBehavior>, }, AttachPartition { partition: Partition, }, DetachPartition { partition: Partition, }, FreezePartition { partition: Partition, with_name: Option<Ident>, }, UnfreezePartition { partition: Partition, with_name: Option<Ident>, }, DropPrimaryKey { drop_behavior: Option<DropBehavior>, }, DropForeignKey { name: Ident, drop_behavior: Option<DropBehavior>, }, DropIndex { name: Ident, }, EnableAlwaysRule { name: Ident, }, EnableAlwaysTrigger { name: Ident, }, EnableReplicaRule { name: Ident, }, EnableReplicaTrigger { name: Ident, }, EnableRowLevelSecurity, ForceRowLevelSecurity, NoForceRowLevelSecurity, EnableRule { name: Ident, }, EnableTrigger { name: Ident, }, RenamePartitions { old_partitions: Vec<Expr>, new_partitions: Vec<Expr>, }, ReplicaIdentity { identity: ReplicaIdentity, }, AddPartitions { if_not_exists: bool, new_partitions: Vec<Partition>, }, DropPartitions { partitions: Vec<Expr>, if_exists: bool, }, RenameColumn { old_column_name: Ident, new_column_name: Ident, }, RenameTable { table_name: RenameTableNameKind, }, ChangeColumn { old_name: Ident, new_name: Ident, data_type: DataType, options: Vec<ColumnOption>, column_position: Option<MySQLColumnPosition>, }, ModifyColumn { col_name: Ident, data_type: DataType, options: Vec<ColumnOption>, column_position: Option<MySQLColumnPosition>, }, RenameConstraint { old_name: Ident, new_name: Ident, }, AlterColumn { column_name: Ident, op: AlterColumnOperation, }, SwapWith { table_name: ObjectName, }, SetTblProperties { table_properties: Vec<SqlOption>, }, OwnerTo { new_owner: Owner, }, ClusterBy { exprs: Vec<Expr>, }, DropClusteringKey, SuspendRecluster, ResumeRecluster, Refresh { subpath: Option<String>, }, Suspend, Resume, Algorithm { equals: bool, algorithm: AlterTableAlgorithm, }, Lock { equals: bool, lock: AlterTableLock, }, AutoIncrement { equals: bool, value: ValueWithSpan, }, ValidateConstraint { name: Ident, }, SetOptionsParens { options: Vec<SqlOption>, },
}
An ALTER TABLE (Statement::AlterTable) operation

Variants



AddConstraint

ADD <table_constraint> [NOT VALID]

Fields

constraint: TableConstraint

The table constraint to add.

not_valid: bool

Whether the constraint should be marked NOT VALID.



AddColumn

ADD [COLUMN] [IF NOT EXISTS] <column_def>

Fields

column_keyword: bool

[COLUMN].

if_not_exists: bool

[IF NOT EXISTS]

column_def: ColumnDef

<column_def>.

column_position: Option<MySQLColumnPosition>

MySQL ALTER TABLE only [FIRST | AFTER column_name]



AddProjection

ADD PROJECTION [IF NOT EXISTS] name ( SELECT <COLUMN LIST EXPR> [GROUP BY] [ORDER BY])

Note: this is a ClickHouse-specific operation. Please refer to ClickHouse

Fields

if_not_exists: bool

Whether IF NOT EXISTS was specified.

name: Ident

Name of the projection to add.

select: ProjectionSelect

The projection’s select clause.



DropProjection

DROP PROJECTION [IF EXISTS] name

Note: this is a ClickHouse-specific operation. Please refer to ClickHouse

Fields

if_exists: bool

Whether IF EXISTS was specified.

name: Ident

Name of the projection to drop.



MaterializeProjection

MATERIALIZE PROJECTION [IF EXISTS] name [IN PARTITION partition_name]

Note: this is a ClickHouse-specific operation. Please refer to ClickHouse

Fields

if_exists: bool

Whether IF EXISTS was specified.

name: Ident

Name of the projection to materialize.

partition: Option<Ident>

Optional partition name to operate on.



ClearProjection

CLEAR PROJECTION [IF EXISTS] name [IN PARTITION partition_name]

Note: this is a ClickHouse-specific operation. Please refer to ClickHouse

Fields

if_exists: bool

Whether IF EXISTS was specified.

name: Ident

Name of the projection to clear.

partition: Option<Ident>

Optional partition name to operate on.



DisableRowLevelSecurity

DISABLE ROW LEVEL SECURITY

Note: this is a PostgreSQL-specific operation. Please refer to PostgreSQL documentation



DisableRule

DISABLE RULE rewrite_rule_name

Note: this is a PostgreSQL-specific operation.

Fields

name: Ident

Name of the rule to disable.



DisableTrigger

DISABLE TRIGGER [ trigger_name | ALL | USER ]

Note: this is a PostgreSQL-specific operation.

Fields

name: Ident

Name of the trigger to disable (or ALL/USER).



DropConstraint

DROP CONSTRAINT [ IF EXISTS ] <name>

Fields

if_exists: bool

IF EXISTS flag for dropping the constraint.

name: Ident

Name of the constraint to drop.

drop_behavior: Option<DropBehavior>

Optional drop behavior (CASCADE/RESTRICT).



DropColumn

DROP [ COLUMN ] [ IF EXISTS ] <column_name> [ , <column_name>, ... ] [ CASCADE ]

Fields

has_column_keyword: bool

Whether the COLUMN keyword was present.

column_names: Vec<Ident>

Names of columns to drop.

if_exists: bool

Whether IF EXISTS was specified for the columns.

drop_behavior: Option<DropBehavior>

Optional drop behavior for the column removal.



AttachPartition

ATTACH PART|PARTITION <partition_expr> Note: this is a ClickHouse-specific operation, please refer to ClickHouse

Fields

partition: Partition

Partition expression to attach.



DetachPartition

DETACH PART|PARTITION <partition_expr> Note: this is a ClickHouse-specific operation, please refer to ClickHouse

Fields

partition: Partition

Partition expression to detach.



FreezePartition

FREEZE PARTITION <partition_expr> Note: this is a ClickHouse-specific operation, please refer to ClickHouse

Fields

partition: Partition

Partition to freeze.

with_name: Option<Ident>

Optional name for the freeze operation.



UnfreezePartition

UNFREEZE PARTITION <partition_expr> Note: this is a ClickHouse-specific operation, please refer to ClickHouse

Fields

partition: Partition

Partition to unfreeze.

with_name: Option<Ident>

Optional name associated with the unfreeze operation.



DropPrimaryKey

DROP PRIMARY KEY

MySQL Snowflake

Fields

drop_behavior: Option<DropBehavior>

Optional drop behavior for the primary key (CASCADE/RESTRICT).



DropForeignKey

DROP FOREIGN KEY <fk_symbol>

MySQL Snowflake

Fields

name: Ident

Foreign key symbol/name to drop.

drop_behavior: Option<DropBehavior>

Optional drop behavior for the foreign key.



DropIndex

DROP INDEX <index_name>

Fields

name: Ident

Name of the index to drop.



EnableAlwaysRule

ENABLE ALWAYS RULE rewrite_rule_name

Note: this is a PostgreSQL-specific operation.

Fields

name: Ident

Name of the rule to enable.



EnableAlwaysTrigger

ENABLE ALWAYS TRIGGER trigger_name

Note: this is a PostgreSQL-specific operation.

Fields

name: Ident

Name of the trigger to enable.



EnableReplicaRule

ENABLE REPLICA RULE rewrite_rule_name

Note: this is a PostgreSQL-specific operation.

Fields

name: Ident

Name of the replica rule to enable.



EnableReplicaTrigger

ENABLE REPLICA TRIGGER trigger_name

Note: this is a PostgreSQL-specific operation.

Fields

name: Ident

Name of the replica trigger to enable.



EnableRowLevelSecurity

ENABLE ROW LEVEL SECURITY

Note: this is a PostgreSQL-specific operation. Please refer to PostgreSQL documentation



ForceRowLevelSecurity

FORCE ROW LEVEL SECURITY

Note: this is a PostgreSQL-specific operation. Please refer to PostgreSQL documentation



NoForceRowLevelSecurity

NO FORCE ROW LEVEL SECURITY

Note: this is a PostgreSQL-specific operation. Please refer to PostgreSQL documentation



EnableRule

ENABLE RULE rewrite_rule_name

Note: this is a PostgreSQL-specific operation.

Fields

name: Ident

Name of the rule to enable.



EnableTrigger

ENABLE TRIGGER [ trigger_name | ALL | USER ]

Note: this is a PostgreSQL-specific operation.

Fields

name: Ident

Name of the trigger to enable (or ALL/USER).



RenamePartitions

RENAME TO PARTITION (partition=val)

Fields

old_partitions: Vec<Expr>

Old partition expressions to be renamed.

new_partitions: Vec<Expr>

New partition expressions corresponding to the old ones.



ReplicaIdentity

REPLICA IDENTITY { DEFAULT | USING INDEX index_name | FULL | NOTHING }

Note: this is a PostgreSQL-specific operation. Please refer to PostgreSQL documentation

Fields

identity: ReplicaIdentity

Replica identity setting to apply.



AddPartitions

Add Partitions

Fields

if_not_exists: bool

Whether IF NOT EXISTS was present when adding partitions.

new_partitions: Vec<Partition>

New partitions to add.



DropPartitions

DROP PARTITIONS ... / drop partitions from the table.

Fields

partitions: Vec<Expr>

Partitions to drop (expressions).

if_exists: bool

Whether IF EXISTS was specified for dropping partitions.



RenameColumn

RENAME [ COLUMN ] <old_column_name> TO <new_column_name>

Fields

old_column_name: Ident

Existing column name to rename.

new_column_name: Ident

New column name.



RenameTable

RENAME TO <table_name>

Fields

table_name: RenameTableNameKind

The new table name or renaming kind.



ChangeColumn

Change an existing column’s name, type, and options.

Fields

old_name: Ident

Old column name.

new_name: Ident

New column name.

data_type: DataType

New data type for the column.

options: Vec<ColumnOption>

Column options to apply after the change.

column_position: Option<MySQLColumnPosition>

MySQL-specific column position (FIRST/AFTER).



ModifyColumn

Modify an existing column’s type and options.

Fields

col_name: Ident

Column name to modify.

data_type: DataType

New data type for the column.

options: Vec<ColumnOption>

Column options to set.

column_position: Option<MySQLColumnPosition>

MySQL-specific column position (FIRST/AFTER).



RenameConstraint

RENAME CONSTRAINT <old_constraint_name> TO <new_constraint_name>

Note: this is a PostgreSQL-specific operation. Rename a constraint on the table.

Fields

old_name: Ident

Existing constraint name.

new_name: Ident

New constraint name.



AlterColumn

ALTER [ COLUMN ] Alter a specific column with the provided operation.

Fields

column_name: Ident

The column to alter.

op: AlterColumnOperation

Operation to apply to the column.



SwapWith

‘SWAP WITH <table_name>’

Note: this is Snowflake specific https://docs.snowflake.com/en/sql-reference/sql/alter-table

Fields

table_name: ObjectName

Table name to swap with.



SetTblProperties

‘SET TBLPROPERTIES ( { property_key [ = ] property_val } [, …] )’

Fields

table_properties: Vec<SqlOption>

Table properties specified as SQL options.



OwnerTo

OWNER TO { <new_owner> | CURRENT_ROLE | CURRENT_USER | SESSION_USER }

Note: this is PostgreSQL-specific https://www.postgresql.org/docs/current/sql-altertable.html

Fields

new_owner: Owner

The new owner to assign to the table.



ClusterBy

Fields

exprs: Vec<Expr>

Expressions used for clustering the table.



DropClusteringKey

Remove the clustering key from the table.



SuspendRecluster

Suspend background reclustering operations.



ResumeRecluster

Resume background reclustering operations.



Refresh

Fields

subpath: Option<String>

Optional subpath for external table refresh



Suspend

SUSPEND

Note: this is Snowflake specific for dynamic tables https://docs.snowflake.com/en/sql-reference/sql/alter-table



Resume

RESUME

Note: this is Snowflake specific for dynamic tables https://docs.snowflake.com/en/sql-reference/sql/alter-table



Algorithm

ALGORITHM [=] { DEFAULT | INSTANT | INPLACE | COPY }

MySQL-specific table alter algorithm.

Fields

equals: bool

Whether the = sign was used (ALGORITHM = ...).

algorithm: AlterTableAlgorithm

The algorithm to use for the alter operation (MySQL-specific).



Lock

LOCK [=] { DEFAULT | NONE | SHARED | EXCLUSIVE }

MySQL-specific table alter lock.

Fields

equals: bool

Whether the = sign was used (LOCK = ...).

lock: AlterTableLock

The locking behavior to apply (MySQL-specific).



AutoIncrement

AUTO_INCREMENT [=] <value>

MySQL-specific table option for raising current auto increment value.

Fields

equals: bool

Whether the = sign was used (AUTO_INCREMENT = ...).

value: ValueWithSpan

Value to set for the auto-increment counter.



ValidateConstraint

VALIDATE CONSTRAINT <name>

Fields

name: Ident

Name of the constraint to validate.



SetOptionsParens

Arbitrary parenthesized SET options.

Example:

SET (scale_factor = 0.01, threshold = 500)`

PostgreSQL

Fields

options: Vec<SqlOption>

Parenthesized options supplied to SET (...).